#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_C180_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_C180_HPP_INCLUDED

#include <boost/simd/constant/include/constants/c180.hpp>

#endif
